@@ -1,7 +1,13 @@
-#!/usr/bin/perl
-
 package Crypt::Random::Source::Base::Proc;
-use Moose;
+BEGIN {
+  $Crypt::Random::Source::Base::Proc::AUTHORITY = 'cpan:NUFFIN';
+}
+BEGIN {
+  $Crypt::Random::Source::Base::Proc::VERSION = '0.06';
+}
+# ABSTRACT: Base class for helper processes (e.g. C<openssl>)
+
+use Any::Moose;
 
 extends qw(Crypt::Random::Source::Base::Handle);
 
@@ -25,16 +31,17 @@ sub open_handle {
 	return $fh;
 }
 
-__PACKAGE__
+1;
+
 
 __END__
-
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-Crypt::Random::Source::Base::Proc - Base class for helper processes (e.g.
-C<openssl>)
+Crypt::Random::Source::Base::Proc - Base class for helper processes (e.g. C<openssl>)
 
 =head1 SYNOPSIS
 
@@ -49,24 +56,28 @@ C<openssl>)
 This is a base class for using command line utilities which output random data
 on STDOUT as L<Crypt::Random::Source> objects.
 
-=head1 METHODS
+=head1 ATTRIBUTES
 
-=over 4
-
-=item command
+=head2 command
 
 An array reference or string that is the command to run.
 
-=back
+=head1 METHODS
 
-=over 4
-
-=item open_handle
+=head2 open_handle
 
 Opens a pipe for reading using C<command>.
 
-=back
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
