@@ -1,7 +1,13 @@
-#!/usr/bin/perl
-
 package Crypt::Random::Source::Base::RandomDevice;
-use Moose;
+BEGIN {
+  $Crypt::Random::Source::Base::RandomDevice::AUTHORITY = 'cpan:NUFFIN';
+}
+BEGIN {
+  $Crypt::Random::Source::Base::RandomDevice::VERSION = '0.06';
+}
+# ABSTRACT: Base class for random devices
+
+use Any::Moose;
 
 extends qw(Crypt::Random::Source::Base::File);
 
@@ -29,12 +35,14 @@ sub default_path {
 	die "abstract";
 }
 
-__PACKAGE__
+1;
+
 
 __END__
-
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Crypt::Random::Source::Base::RandomDevice - Base class for random devices
@@ -54,5 +62,16 @@ This is a base class for random device sources.
 See L<Crypt::Random::Source::Strong::devrandom> and
 L<Crypt::Random::Source::Weak::devurandom> for actual implementations.
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
